const svg = d3.select('svg');
const margin = { top: 20, right: 20, bottom: 30, left: 40 };
const width =
  +svg.attr('width') - margin.left - margin.right;
const height =
  +svg.attr('height') - margin.top - margin.bottom;

const x = d3
  .scaleBand()
  .rangeRound([0, width])
  .padding(0.1);
const y = d3.scaleLinear().rangeRound([height, 0]);
const z = d3.scaleOrdinal(d3.schemeCategory10);

const g = svg
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left},${margin.top})`,
  );

d3.csv('data.csv').then(function (data) {
  const keys = data.columns.slice(1);

  data.forEach((d) => {
    let total = 0;
    keys.forEach((key) => {
      total += d[key] = +d[key];
    });
    d.total = total;
  });

  x.domain(data.map((d) => d.Month));
  y.domain([0, d3.max(data, (d) => d.total)]).nice();
  z.domain(keys);

  g.append('g')
    .selectAll('g')
    .data(d3.stack().keys(keys)(data))
    .enter()
    .append('g')
    .attr('fill', (d) => z(d.key))
    .selectAll('rect')
    .data((d) => d)
    .enter()
    .append('rect')
    .attr('x', (d) => x(d.data.Month))
    .attr('y', (d) => y(d[1]))
    .attr('height', (d) => y(d[0]) - y(d[1]))
    .attr('width', x.bandwidth());

  g.append('g')
    .attr('class', 'axis')
    .attr('transform', `translate(0,${height})`)
    .call(d3.axisBottom(x));

  g.append('g')
    .attr('class', 'axis')
    .call(d3.axisLeft(y).ticks(null, 's'))
    .append('text')
    .attr('x', 2)
    .attr('y', y(y.ticks().pop()) + 0.5)
    .attr('dy', '0.32em')
    .attr('fill', '#000')
    .attr('font-weight', 'bold')
    .attr('text-anchor', 'start')
    .text('Sales');
});
